@@ -1,14 +1,17 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 import time
 import board
-from adafruit_lsm6ds import LSM6DSOX as LSM6DS
+from adafruit_lsm6ds.lsm6dsox import LSM6DSOX as LSM6DS
 
 # To use LSM6DS33, comment out the LSM6DSOX import line
 # and uncomment the next line
-# from adafruit_lsm6ds import LSM6DS33 as LSM6DS
+# from adafruit_lsm6ds.lsm6ds33 import LSM6DS33 as LSM6DS
 
 # To use ISM330DHCX, comment out the LSM6DSOX import line
 # and uncomment the next line
-# from adafruit_lsm6ds import ISM330DHCX as LSM6DS
+# from adafruit_lsm6ds.lsm330dhcx import ISM330DHCX as LSM6DS
 
 from adafruit_lis3mdl import LIS3MDL
 
